DecodeAction

Enum DecodeAction 

pub enum DecodeAction<Value> {
    NeedInput {
        required_total: usize,
    },
    Skip {
        consumed: NonZeroUsize,
    },
    Emit {
        value: Value,
        consumed: NonZeroUsize,
    },
}
Action selected after a codec decode attempt fails during transcode.

Type Parameters

  • Value: Decoded output value type.

Variants



NeedInput

More source units are needed before a value can be produced.

When returned by a decode hook, required_total must be greater than the hook context’s available input count. Returning a value that is already satisfied is a hook contract violation and panics in the engine.

Fields

required_total: usize

Total units required from the current value start.



Skip

Consume invalid input without producing output.

When returned by a decode hook, consumed must not exceed the hook context’s available input count. Over-consuming is a hook contract violation and panics in the engine.

Fields

consumed: NonZeroUsize

Source units to consume.



Emit

Produce one value and consume source units.

When returned by a decode hook, consumed must not exceed the hook context’s available input count. Over-consuming is a hook contract violation and panics in the engine.

Fields

value: Value

Value to write to the output buffer.

consumed: NonZeroUsize

Source units to consume.