CodecValueDecoder

Struct CodecValueDecoder 

pub struct CodecValueDecoder<C>
where C: Codec,
{ /* private fields */ }
Decodes one encoded unit slice into one owned value by using a Codec.

CodecValueDecoder is the default bridge from the low-level unchecked Codec contract to the convenience-layer ValueDecoder contract. The supplied input slice must contain exactly one encoded value. After a successful decode, the adapter calls Codec::decode_flush to reset decode-side stream state for the next call.

Type Parameters

  • C: Low-level codec used to decode one value.

Implementations

Source

impl<C> CodecValueDecoder<C>
where C: Codec,

pub fn new(codec: C) -> Self

Creates a decoder backed by codec.

Parameters
  • codec: Low-level codec used to decode one value.
Returns

Returns a value decoder adapter for the supplied codec.

Panics

In debug builds, panics when the supplied codec violates the Codec::MIN_UNITS_PER_VALUE / Codec::MAX_UNITS_PER_VALUE ordering invariant. Release builds skip this check because the invariant is the responsibility of the Codec implementation.