DecodeContext

Struct DecodeContext 

pub struct DecodeContext {
    pub input_start: usize,
    pub input_index: usize,
    pub output_start: usize,
    pub output_index: usize,
    pub available: usize,
}
Context for one codec decode attempt inside a buffered decoder engine.

Fields

input_start: usize

Absolute source index where this transcode call starts.

input_index: usize

Absolute source index where the attempted value starts.

output_start: usize

Absolute output index where this transcode call starts.

output_index: usize

Absolute output index where the next decoded value would be written.

available: usize

Units visible to the codec from input_index.

Implementations

Source

impl DecodeContext

pub const fn new( input_start: usize, input_index: usize, output_start: usize, output_index: usize, available: usize, ) -> Self

Creates a decode context.

Parameters
  • input_start: Absolute source index where this transcode call starts.
  • input_index: Absolute source index where the attempted value starts.
  • output_start: Absolute output index where this transcode call starts.
  • output_index: Absolute output index where the next value would be written.
  • available: Units visible to the codec from input_index.
Returns

Returns a decode context.

pub const fn input_used(self) -> usize

Returns input units consumed since this transcode call started.

Returns

Returns input_index - input_start.

pub const fn output_written(self) -> usize

Returns output values written since this transcode call started.

Returns

Returns output_index - output_start.