TranscodeStatus

Enum TranscodeStatus 

pub enum TranscodeStatus {
    Complete,
    NeedInput {
        input_index: usize,
        required: usize,
        available: usize,
    },
    NeedOutput {
        output_index: usize,
        required: usize,
        available: usize,
    },
}
Reports why a crate::Transcoder stopped converting input.

Variants



Complete

All currently supplied input was consumed.



NeedInput

More input is needed to complete the next output value.

If the caller has reached EOF, it should call crate::Transcoder::finish so the transcoder can finalize or reject the incomplete stream state.

  • input_index: Absolute input index where input ended while decoding.
  • required: Number of additional input units required to continue.
  • available: Number of input units currently available from the current input position.

Fields

input_index: usize

Absolute input index where input ended.

required: usize

Number of additional input units required to continue.

available: usize

Number of input units currently available.



NeedOutput

More output capacity is needed before conversion can continue.

  • output_index: Absolute output index where output ended while decoding.
  • required: Number of additional output units required to continue.
  • available: Number of output units currently available from the current output position.

Fields

output_index: usize

Absolute output index where output ended.

required: usize

Number of additional output units required to continue.

available: usize

Number of output units currently available.