pub struct CodecValueDecoder<C> { /* private fields */ }Expand description
Decodes one encoded unit slice into one owned value by using a Codec.
CodecValueDecoder is the default bridge from the low-level unchecked
Codec contract to the convenience-layer ValueDecoder contract. The
supplied input slice must contain exactly one encoded value. Successfully
decoded prefixes followed by extra units are reported as trailing input.
Type Parameters
C: Low-level codec used to decode one value.
Implementations