CodecValueEncoder

Struct CodecValueEncoder 

pub struct CodecValueEncoder<C> { /* private fields */ }
Encodes one borrowed value into owned units by using a Codec.

CodecValueEncoder is the default bridge from the low-level unchecked Codec contract to the convenience-layer ValueEncoder contract. It allocates codec.max_units_per_value() output units, calls Codec::encode_unchecked with the borrowed value, then truncates the owned output to the number of units actually written.

Type Parameters

  • C: Low-level codec used to encode one value.

Implementations

Source

impl<C> CodecValueEncoder<C>

pub const fn new(codec: C) -> Self

Creates an encoder backed by codec.

Parameters
  • codec: Low-level codec used to encode one value.
Returns

Returns a value encoder adapter for the supplied codec.